@@ -49,6 +49,8 @@
 
 package com.openexchange.mobile.api.facade.auth;
 
+import com.openexchange.mobile.api.facade.configuration.HostConfiguration;
+
 import lombok.AccessLevel;
 import lombok.AllArgsConstructor;
 import lombok.NonNull;
@@ -82,6 +84,10 @@ public class LoginCredentials {
     @NonFinal
     String forwardedFor;
 
+    @Wither
+    @NonFinal
+    String forwardedProto;
+
     @Wither
     @NonFinal
     String userAgent;
@@ -90,4 +96,8 @@ public class LoginCredentials {
     @NonFinal
     String trackingId;
 
+    @Wither
+    @NonFinal
+    HostConfiguration hostConfiguration;
+
 }
\ No newline at end of file
