@@ -116,6 +116,11 @@ public class DefaultConnectorFactory implements ConnectorFactory {
         return new CreateFolderConnector(configuration, sessionData, parentFolderId, name);
     }
 
+    @Override
+    public UpdateFolderConnector getUpdateFolderConnector(SessionData sessionData, String folderId, String newParentFolderId, String newName) {
+        return new UpdateFolderConnector(configuration, sessionData, folderId, newParentFolderId, newName);
+    }
+
     @Override
     public DeleteFolderConnector getDeleteFolderConnector(SessionData sessionData, String folderId) {
         return new DeleteFolderConnector(configuration, sessionData, folderId);
