@@ -83,6 +83,7 @@ import org.apache.http.impl.client.BasicCookieStore;
 import org.apache.http.impl.client.CloseableHttpClient;
 import org.apache.http.impl.client.HttpClients;
 import org.apache.http.ssl.SSLContextBuilder;
+import org.apache.http.util.TextUtils;
 
 @UtilityClass
 public class RequestUtil {
@@ -121,7 +122,7 @@ public class RequestUtil {
 
     private static final int USER_AGENT_MAXLEN = 100;
 
-    private static final Pattern USER_AGENT_PATTERN = Pattern.compile("^(.*)\\.(.*)\\.Mail/(\\S*) \\(OS:(.*); device:(.*)\\)$");
+    private static final Pattern USER_AGENT_PATTERN = Pattern.compile("^(.*)\\.(.*)\\.Mail/(\\S*) \\(.*\\)$");
 
     private static final String HEADER_CACHE_CONTROL = "Cache-control";
 
@@ -173,18 +174,16 @@ public class RequestUtil {
             throw ApiFacadeException.badRequest(ApiFacadeException.Code.MISSING_COOKIES, "Cookies missing");
         }
         String hostname = getHostHeader(request);
-        String xHostname = getXHostHeader(request);
         String userAgent = getUserAgent(request);
         String trackingId = getTrackingId(request);
         String contextId = getContextId(request);
         String userId = getUserId(request);
-        UserAgentInfo userAgentInfo = parseUserAgent(userAgent);
-        HostConfiguration hostConfiguration = ConfigurationHelper.getConfiguration(hostname, xHostname, userAgentInfo);
-        checkUserAgent(userAgentInfo, hostConfiguration);
-        return enhanceSessionData(request, hostConfiguration, hostname, xHostname, userAgent, trackingId, contextId, userId, new SessionData(session, cookies));
+        HostConfiguration hostConfiguration = ConfigurationHelper.getConfiguration(request);
+        checkUserAgent(userAgent, hostConfiguration);
+        return enhanceSessionData(request, hostConfiguration, hostname, userAgent, trackingId, contextId, userId, new SessionData(session, cookies));
     }
 
-    public static SessionData enhanceSessionData(HttpServletRequest request, HostConfiguration configuration, String hostname, String xHostname, String userAgent, String trackingId, String contextId, String userId, SessionData sessionData) {
+    public static SessionData enhanceSessionData(HttpServletRequest request, HostConfiguration configuration, String hostname, String userAgent, String trackingId, String contextId, String userId, SessionData sessionData) {
         if (trackingId != null) {
             sessionData.setProperty(SessionData.PROPERTY_TRACKING_ID, trackingId);
         }
@@ -200,7 +199,6 @@ public class RequestUtil {
         }
         return sessionData
                 .withHost(hostname)
-                .withXHost(xHostname)
                 .withForwardedFor(getForwardedForWithRemoteIp(request))
                 .withForwardedProto(getForwardedProto(request))
                 .withUserAgent(userAgent)
@@ -215,7 +213,11 @@ public class RequestUtil {
         return userAgent;
     }
 
-    public void checkUserAgent(UserAgentInfo userAgentInfo, HostConfiguration hostConfiguration) {
+    public void checkUserAgent(String userAgent, HostConfiguration hostConfiguration) {
+        if (Strings.isEmpty(userAgent)) {
+            throw ApiFacadeException.missingHeader(HEADER_USER_AGENT);
+        }
+        UserAgentInfo userAgentInfo = parseUserAgent(userAgent);
         if (!hostConfiguration.isAllowedBrand(userAgentInfo.getBrand())) {
             throw ApiFacadeException.forbidden();
         }
@@ -235,7 +237,7 @@ public class RequestUtil {
         }
         Semver clientVersion = new Semver(clientVersionStr, SemverType.LOOSE);
         Semver minimumClientVersion = new Semver(minimumClientVersionStr, SemverType.LOOSE);
-        return minimumClientVersion.isLowerThanOrEqualTo(clientVersion);
+        return !clientVersion.isLowerThan(minimumClientVersion);
     }
 
     private String getMinimumClientVersion(Map<String, String> minimumClientVersions, UserAgentInfo userAgentInfo) {
@@ -304,25 +306,20 @@ public class RequestUtil {
     }
 
     public UserAgentInfo parseUserAgent(String userAgent) {
-        if (Strings.isEmpty(userAgent)) {
-            throw ApiFacadeException.missingHeader(HEADER_USER_AGENT);
-        }
-        if (userAgent.length() > USER_AGENT_MAXLEN) {
+        if (TextUtils.isEmpty(userAgent) || userAgent.length() > USER_AGENT_MAXLEN) {
             throw ApiFacadeException.invalidUserAgent();
         }
         Matcher matcher = USER_AGENT_PATTERN.matcher(userAgent);
         if (!matcher.find()) {
             throw ApiFacadeException.invalidUserAgent();
         }
-        if (matcher.groupCount() != 5) {
+        if (matcher.groupCount() != 3) {
             throw ApiFacadeException.invalidUserAgent();
         }
         String brand = matcher.group(1);
         String platform = matcher.group(2);
         String clientVersion = matcher.group(3);
-        String osVersion = matcher.group(4).trim();
-        String device = matcher.group(5).trim();
-        return new UserAgentInfo(brand, platform, clientVersion, osVersion, device);
+        return new UserAgentInfo(brand, platform, clientVersion);
     }
 
     /*private*/ String getIfNoneMatch(HttpServletRequest request) {
@@ -334,11 +331,11 @@ public class RequestUtil {
     }
 
     public String getHostHeader(HttpServletRequest request) {
-        return request.getHeader(HEADER_HOST);
-    }
-
-    public String getXHostHeader(HttpServletRequest request) {
-        return request.getHeader(HEADER_X_HOST);
+        String value = request.getHeader(HEADER_X_HOST);
+        if (value == null) {
+            value = request.getHeader(HEADER_HOST);
+        }
+        return value;
     }
 
     public String getLanguage(HttpServletRequest request) {
